function MultiCompartmentalModel

%% clear screen
clc

%% declare global variables
global data;
global datas;
global Parameter;

%% load experimental data
PREdata= load('CHO.txt'); %without SORLA
PREdatas= load('CHO_S.txt'); %with SORLA

%% open file to record parameter values that will be estimated
fid = fopen('MultiCompartmentalModel.txt', 'at');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%% sort experimental data according to the total amount of APP measured in the experiments
data = sortrows(PREdata,1); %without SORLA
datas = sortrows(PREdatas,1); %with SORLA

%% data sets
%without SORLA
xdata = data(:,1).* 50;%convert total APP from nM into fmol
ydataA = data(:,2);%sAPPa
ydataB = data(:,3); %sAPPb
% with SORLA
xdatas = datas(:,1) .* 50;%convert total APP from nM into fmol
ydataAs = datas(:,2);%sAPPa
ydataBs = datas(:,3); %sAPPb
% back up vectors of the experimental data
xdata8=xdata;
ydataA8=ydataA;
ydataB8=ydataB;
xdata8s=xdatas;
ydataA8s=ydataAs;
ydataB8s=ydataBs;
% a copy of vector APP in nM for plotting purpose
xdata8P= data(:,1);
xdata8sP= datas(:,1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%% initial loop
loop=1;
%% row denotes the number of repetitions
for row=1:500
    tempflag=row 
 
%% In the process of parameter estimation, the following are assumed
% % Kc3  denotes Kc3.* (Kc2.^2)from mathematical model in Section~\ref{sec:MultiCompartmentmodel}
% % Kb3  denotes Kb3.* (Kb2.^2) from mathematical model in Section~\ref{sec:MultiCompartmentmodel}
% % Kg3  denotes Kg3.* (Kg2.^2) from mathematical model in Section~\ref{sec:MultiCompartmentmodel}
% % Kcs1 denotes Kcs1.* Kg1 from mathematical model in Section~\ref{sec:MultiCompartmentmodel}
% % Kcs2 denotes Kcs2.* (Kg3.* (Kg2.^2)) from mathematical model in Section~\ref{sec:MultiCompartmentmodel}
% % Kee1 denotes Kee1.* (Kcs1.* Kg1) from mathematical model in Section~\ref{sec:MultiCompartmentmodel}
% % Kee2 denotes Kee2.* (Kcs2.* Kg3.* (Kg2.^2)) from mathematical model in Section~\ref{sec:MultiCompartmentmodel}
% % Ks1 denotes Ks1.* Kg1 from mathematical model in Section~\ref{sec:MultiCompartmentmodel}
% % Ks2 denotes Ks2.* Kg2 from mathematical model in Section~\ref{sec:MultiCompartmentmodel}
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%% initial parameter values
   Atot=100* rand(1);  Btot=100* rand(1); k6d=100* rand(1);  Kmad=100* rand(1);  k4d=100* rand(1);  Kmbd=100* rand(1);    
   k6=100* rand(1);   Kma=100* rand(1);   k4=100* rand(1);   Kmb=100* rand(1);    Kg1=100* rand(1);  Kg2=100* rand(1);
   Kcs1=100* rand(1); Kcs2=100* rand(1); Kee1=100* rand(1); Kee2=100* rand(1); Kc1=100* rand(1);  Kc2=100* rand(1);
   Kb1=100* rand(1);  Kb2=100* rand(1);   Kg3=100* rand(1);  Kc3=100* rand(1);   Kb3=100* rand(1);   
   Ks1=100* rand(1);  Ks2=100* rand(1);  SORtotm=100* rand(1); SORtotd=100* rand(1);

 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%% call the nonlinear least square function lsqnonlin()
options = optimset('PrecondBandWidth',0);
%27 parameters all in all
[Parameter, resi] = lsqnonlin(@mycurve,[Atot, Btot, k6d, Kmad, k4d, Kmbd, k6, Kma, k4, Kmb, Kg1, Kg2, Kcs1, Kcs2, Kee1, Kee2, Kc1, Kc2, Kb1, Kb2, Kg3, Kc3, Kb3, Ks1, Ks2, SORtotm, SORtotd],[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0],[],options)
 
Atot=Parameter(1); Btot=Parameter(2); k6d=Parameter(3);   Kmad=Parameter(4);  k4d=Parameter(5); Kmbd=Parameter(6); 
k6=Parameter(7);    Kma=Parameter(8);   k4=Parameter(9);    Kmb=Parameter(10);    Kg1=Parameter(11);  Kg2=Parameter(12);  
Kcs1=Parameter(13); Kcs2=Parameter(14); Kee1=Parameter(15); Kee2=Parameter(16); Kc1=Parameter(17);  Kc2=Parameter(18);  
Kb1=Parameter(19);  Kb2=Parameter(20);  Kg3=Parameter(21);  Kc3=Parameter(22);  Kb3=Parameter(23);   
Ks1=Parameter(24);  Ks2=Parameter(25);  SORtotm=Parameter(26);  SORtotd=Parameter(27);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%% to check if there is negative parameter estimated
if (Parameter(1)>0 && Parameter(2)>0 && Parameter(3)>0 && Parameter(4)>0 && Parameter(5)>0 && Parameter(6)>0 && Parameter(7)>0 && Parameter(8)>0 && Parameter(9)>0 && Parameter(10)>0 && Parameter(11)>1 && Parameter(12)>1 && Parameter(13)>0 && Parameter(14)>0 && Parameter(15)>0 && Parameter(16)>0 && Parameter(17)>1 && Parameter(18)>1 && Parameter(19)>1 && Parameter(20)>1 && Parameter(21)>0 && Parameter(22)>0 && Parameter(23)>0 && Parameter(24)>0 && Parameter(25)>0 && Parameter(26)>0 && Parameter(27)>0 )
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%% Mathematical representation
APP= appFSOLVE'; %APP_init solved given APP_tot w/ o SORLA
APPms= appFSOLVEms'; %APPms *  Kg1 denotes APP_G1 in the presence of SORLA
APPds= appFSOLVEds'; %APPds *  Kg2 denotes APP_G2 in the presence of SORLA
datum= xdata8(:,1); 
datums= xdata8s(:,1);
% Recall that
% Kc3  denotes Kc3.* (Kc2.^2)
% Kb3  denotes Kb3.* (Kb2.^2)
% Kg3  denotes Kg3.* (Kg2.^2)
% Kcs1 denotes Kcs1.* Kg1
% Kcs2 denotes Kcs2.* (Kg3.* (Kg2.^2))
% Kee1 denotes Kee1.* (Kcs1.* Kg1)
% Kee2 denotes Kee2.* (Kcs2.* Kg3.* (Kg2.^2))
% Ks1 denotes Ks1.* Kg1
% Ks2 denotes Ks2.* Kg2
 
%% without SORLA
% alpha denotes alpha_init
% beta denotes beta_init 
% appTOT denotes APP_init

% see Equations~\ref{eq:alpha5}
	alpha   = (- (1+ Kc2+ Kc1.* (1+ Kcs1.* APP./ Kma)) +  sqrt((1+ Kc2+ Kc1.* (1+ Kcs1.* APP./ Kma)).^2- 4.* (2.* Kc3.* (1+ Kcs2.* APP.^2./ Kmad)).* (- Atot)))./ (2.* (2.* Kc3.* (1+ Kcs2.* APP.^2./ Kmad)));
% see Equations~\ref{eq:beta5}
beta    = (- (1+ Kb2+ Kb1.* (1+ Kee1.* APP./ Kmb)) +  sqrt((1+ Kb2+ Kb1.* (1+ Kee1.* APP./ Kmb)).^2- 4.* (2.* Kb3.* (1+ Kee2.* APP.^2./ Kmbd)).* (- Btot)))./ (2.* (2.* Kb3.* (1+ Kee2.* APP.^2./ Kmbd)));
% see Equations~\ref{APPtot2}
appTOT  = APP.* (1+ Kg1+ Kg2+ Kcs1.* (1+ Kc1.* ((- (1+ Kc2+ Kc1.* (1+ Kcs1.* APP./ Kma)) +  sqrt((1+ Kc2+ Kc1.* (1+ Kcs1.* APP./ Kma)).^2- 4.* (2.* Kc3.* (1+ Kcs2.* APP.^2./ Kmad)).* (- Atot)))./ (2.* (2.* Kc3.* (1+ Kcs2.* APP.^2./ Kmad))))./ Kma)+ Kee1.* (1+ Kb1.* ((- (1+ Kb2+ Kb1.* (1+ Kee1.* APP./ Kmb)) +  sqrt((1+ Kb2+ Kb1.* (1+ Kee1.* APP./ Kmb)).^2- 4.* (2.* Kb3.* (1+ Kee2.* APP.^2./ Kmbd)).* (- Btot)))./ (2.* (2.* Kb3.* (1+ Kee2.* APP.^2./ Kmbd))))./ Kmb))+ ... %monomer processing
      2.* (APP.^2).* (Kg3+ Kcs2.* (1+ Kc3.* (((- (1+ Kc2+ Kc1.* (1+ Kcs1.* APP./ Kma)) +  sqrt((1+ Kc2+ Kc1.* (1+ Kcs1.* APP./ Kma)).^2- 4.* (2.* Kc3.* (1+ Kcs2.* APP.^2./ Kmad)).* (- Atot)))./ (2.* (2.* Kc3.* (1+ Kcs2.* APP.^2./ Kmad)))).^2)./ Kmad)+ Kee2.* (1+ Kb3.* (((- (1+ Kb2+ Kb1.* (1+ Kee1.* APP./ Kmb)) +  sqrt((1+ Kb2+ Kb1.* (1+ Kee1.* APP./ Kmb)).^2- 4.* (2.* Kb3.* (1+ Kee2.* APP.^2./ Kmbd)).* (- Btot)))./ (2.* (2.* Kb3.* (1+ Kee2.* APP.^2./ Kmbd)))).^2)./ Kmbd)); %dimer processing 1
 

%% with SORLA
% alphams.* Kc1 denotes alpha_1
% alphads.* Kc2 denotes alpha_2
% betams.* Kb1 denotes beta_1
% betads.* Kb2 denotes beta_2
% Atotms and Atotds denote the conserved amount of alpha in monomer and in dimer, repectively
% Btotms and Btotds denote the conserved amount of beta in monomer and in dimer, repectively
 
% see Equations~\ref{MonoDimerInitW}~and~\ref{alphaMonoDimWO}
alphams = Atotms./ (Kc1.* (1+ Kcs1.* APPms./ Kma));
alphads = (- Kc2 +  sqrt(Kc2.^2- 4.* (2.* Kc3.* (1+ Kcs2.* (APPds.^2)./ Kmad)).* (- Atotds)))./ (4.* Kc3.* (1+ Kcs2.* (APPds.^2)./ Kmad));

betams  = Btotms./ (Kb1.* (1+ Kee1.* APPms./ Kmb));
betads  = (- Kb2 +  sqrt(Kb2.^2- 4.* (2.* Kb3.* (1+ Kee2.* (APPds.^2)./ Kmbd)).* (- Btotds)))./ (4.* Kb3.* (1+ Kee2.* (APPds.^2)./ Kmbd));

appTOTms    = APPms.* (Kg1+ Kcs1.* (1+ Kc1.* alphams./ Kma)+ Kee1.* (1+ Kb1.* betams./ Kmb))+ ...
      Ks1.* (SORtotm./ (1+  Ks1.* APPms)).* APPms; 
appTOTds    = Kg2.* APPds +  2.* (APPds.^2).* (Kg3+ Kcs2.* (1+ Kc3.* (alphads.^2)./ Kmad)+ Kee2.* (1+ Kb3.* (betads.^2)./ Kmbd))+ ... 
      Ks2.* (SORtotd./ (1+  Ks2.* APPds)).* APPds; 
appTOTs = APP+ appTOTms+ appTOTds;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%% check if the difference between the given appTOT and estimated appTOT
% increment count if 
% (1) the Difference is larger than the threshold value
% (2) free APPs is negative
Diff=abs(appTOT- datum);
Diffs=abs(appTOTs- datums);
u=length(APP);
us=length(APPms);
threshold = 0.00000001;
count=0;
count2=0;
for t=1:u
   if ( Diff(t) > threshold)
        count = count + 1;
   end
   
   if (APP(t) < 0)
         count2 = count2 +  1;
   end  
end

for ts=1:us
   if ( Diffs(ts) > threshold)
        count = count + 1;
   end
   
   if (APPms(ts) < 0)
         count2 = count2 +  1;
   end 
   
   if (APPds(ts) < 0)
         count2 = count2 +  1;
   end  
end

% checkpoint: restart if count or count2 <0
if ((count >0) || (count2 >0))
    continue; 
else
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Plotting: plot the original data (CHO.txt and CHO_S.txt) together with simulation results of the model
% See Equations~\ref{eq:sAPPalpha}~-~\ref{eq:sAPPalphabeta}

appTOT=appTOT./ 50;  %convert back from fmol to nM
appTOTs=appTOTs./ 50; %convert back from fmol to nM
appTOT=vertcat(0,appTOT);
appTOTs=vertcat(0,appTOTs);
appFree=vertcat(0,APP);
appFreems=vertcat(0,APPms);
appFreeds=vertcat(0,APPds);
alpha=vertcat(0,alpha);
beta=vertcat(0,beta);
alphams=vertcat(0,alphams);
alphads=vertcat(0,alphads);
betams=vertcat(0,betams);
betads=vertcat(0,betads);
appM=appFree;
appD=(appFree.^2);
appMs=appFreems;
appDs=(appFreeds.^2);

% without SORLA
figure(3000+ loop)
plot(xdata8P,ydataA8,'k.','MarkerSize',10)
hold on 
fitteda1 = 2.* (Kcs2.* appD).* (Kc3.* (alpha.^2)).* k6d./ Kmad; % sAPPa in dimer processing
fitteda2 = (Kcs1.* appM).* (Kc1.* alpha).*  k6./ Kma; % sAPPa in monomer processing
fitteda1P = fitteda1;
fitteda2P = fitteda2;
fitted = fitteda1P+  fitteda2P;
plot(appTOT,fitteda1P,'g- ','LineWidth',2)%dimer
plot(appTOT,fitteda2P,'m- ','LineWidth',2)%monomer
plot(appTOT,fitted,'k- ','LineWidth',2)
xlabel('APP_{Tot}(nM)');
ylabel('sAPP_\backslash alpha(fmol/ h)');
xlim([0 400])
ylim([0 250])

figure(4000+ loop)
plot(xdata8P,ydataB8,'k.','MarkerSize',10)
hold on
fitted11 = 2.* (Kee2.* appD).* (Kb3.* (beta.^2)).* k4d./ Kmbd; %sAPPb in dimer processing
fitted12 = (Kee1.* appM).* (Kb1.* beta).*  k4./ Kmb; %sAPPb in monomer processing
fitted11P = fitted11;
fitted12P = fitted12;
fitted1=fitted11P+ fitted12P;
plot(appTOT,fitted11P,'g- ','LineWidth',2)%dimer
plot(appTOT,fitted12P,'m- ','LineWidth',2)%monomer
plot(appTOT,fitted1,'k- ','LineWidth',2)
xlabel('APP_{Tot}(nM)'); 
ylabel('sAPP_\backslashbeta(fmol/ h)');
xlim([0 400])
ylim([0 12])
 
% with SORLA
figure(6000+ loop)
plot(xdata8sP,ydataA8s,'k.','MarkerSize',10)
hold on 
fitteda1s = 2.* (Kcs2.* appDs).* (Kc3.* (alphads.^2)).* k6d./ Kmad; %sAPPa in dimer processing
fitteda2s = (Kcs1.* appMs).* (Kc1.* alphams).*  k6./ Kma; %sAPPa in monomer processing
fitteda1Ps = fitteda1s;
fitteda2Ps = fitteda2s;
fitteds = fitteda1Ps+  fitteda2Ps;
plot(appTOTs,fitteda1Ps,'g- ','LineWidth',2)%dimer
plot(appTOTs,fitteda2Ps,'m- ','LineWidth',2)%monomer
plot(appTOTs,fitteds,'k- ','LineWidth',2)
xlabel('APP_{Tot}(nM)'); 
ylabel('sAPP_\backslashalpha(fmol/ h)');
xlim([0 400])
ylim([0 250])
 
figure(7000+ loop)
plot(xdata8sP,ydataB8s,'k.','MarkerSize',10)
hold on
fitted11s = 2.* (Kee2.* appDs).* (Kb3.* (betads.^2)).* k4d./ Kmbd; %sAPPb in dimer processing
fitted12s = (Kee1.* appMs).* (Kb1.* betams).*  k4./ Kmb; %sAPPb in monomer processing
fitted11Ps = fitted11s;
fitted12Ps = fitted12s;
fitted1s=fitted11Ps+ fitted12Ps;
plot(appTOTs,fitted11Ps,'g- ','LineWidth',2)%dimer
plot(appTOTs,fitted12Ps,'m- ','LineWidth',2)%monomer
plot(appTOTs,fitted1s,'k- ','LineWidth',2)
xlabel('APP_{Tot}(nM)'); 
ylabel('sAPP_\backslashbeta(fmol/ h)');
xlim([0 400])
ylim([0 12])
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%% Record residual value and 27 estimated paramters into the text file
fprintf(fid, '%12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f\backslashn', resi, Atot, Btot, k6d, Kmad, k4d, Kmbd, k6, Kma, k4, Kmb, Kg1, Kg2, Kcs1, Kcs2, Kee1, Kee2, Kc1, Kc2, Kb1, Kb2, Kg3, Kc3, Kb3, Ks1, Ks2, SORtotm, SORtotd);

%% increment to the next loop
loop=loop+ 1; 

end
end
end

%% close the file that is opened earlier
fclose(fid);



%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%  Subroutince to calculate the sum of squared of error by Least Square Method
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
function err = mycurve(p)
    
%% initial assumptions:
Atot=p(1);    Btot=p(2); k6d=p(3);   Kmad=p(4); k4d=p(5); Kmbd=p(6); k6=p(7); Kma=p(8); k4=p(9); Kmb=p(10);    
Kg1=p(11);  Kg2=p(12);  Kcs1=p(13); Kcs2=p(14); Kee1=p(15); Kee2=p(16); Kc1=p(17);  Kc2=p(18);
Kb1=p(19);  Kb2=p(20); Kg3=p(21);  Kc3=p(22);  Kb3=p(23);   Ks1=p(24);  Ks2=p(25); SORtotm=p(26); SORtotd=p(27);  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%% create a vector to be used for APPinit, APPmonomer, and APPdimer
P = xdata8(:,1);
w=length(P);
appFSOLVE=zeros(1,w);
Ps = xdata8s(:,1);
ws=length(Ps);
appFSOLVEs=zeros(1,ws);
appFSOLVEms=zeros(1,ws); 
appFSOLVEds=zeros(1,ws); 

%% SOLVE for free APP (i.e.\ APP init) given the total amount of APP (without SORLA): see Equations~\ref{APPtot2}
for j=1:w
func=@(APP)( APP.* (1+ Kg1+ Kg2+ Kcs1.* (1+ Kc1.* ((- (1+ Kc2+ Kc1.* (1+ Kcs1.* APP./ Kma)) +  sqrt((1+ Kc2+ Kc1.* (1+ Kcs1.* APP./ Kma)).^2- 4.* (2.* Kc3.* (1+ Kcs2.* APP.^2./ Kmad)).* (- Atot)))./ (2.* (2.* Kc3.* (1+ Kcs2.* APP.^2./ Kmad))))./ Kma)+ Kee1.* (1+ Kb1.* ((- (1+ Kb2+ Kb1.* (1+ Kee1.* APP./ Kmb)) +  sqrt((1+ Kb2+ Kb1.* (1+ Kee1.* APP./ Kmb)).^2- 4.* (2.* Kb3.* (1+ Kee2.* APP.^2./ Kmbd)).* (- Btot)))./ (2.* (2.* Kb3.* (1+ Kee2.* APP.^2./ Kmbd))))./ Kmb))+  2.* (APP.^2).* (Kg3+ Kcs2.* (1+ Kc3.* (((- (1+ Kc2+ Kc1.* (1+ Kcs1.* APP./ Kma)) +  sqrt((1+ Kc2+ Kc1.* (1+ Kcs1.* APP./ Kma)).^2- 4.* (2.* Kc3.* (1+ Kcs2.* APP.^2./ Kmad)).* (- Atot)))./ (2.* (2.* Kc3.* (1+ Kcs2.* APP.^2./ Kmad)))).^2)./ Kmad)+ Kee2.* (1+ Kb3.* (((- (1+ Kb2+ Kb1.* (1+ Kee1.* APP./ Kmb)) +  sqrt((1+ Kb2+ Kb1.* (1+ Kee1.* APP./ Kmb)).^2- 4.* (2.* Kb3.* (1+ Kee2.* APP.^2./ Kmbd)).* (- Btot)))./ (2.* (2.* Kb3.* (1+ Kee2.* APP.^2./ Kmbd)))).^2)./ Kmbd))-  xdata8(j,1));
appFSOLVE(1,j)=fzero(func,[0 P(j)],optimset('fzero'));
end
 
%% SOLVE for free APP (init) given the total amount of APP (with SORLA)
% Since the experimental data for APP_tot with and without SORLA are not measured in 1- 1 correspondence, thus in order to continue with the analysis of experimental data with SORLA, the computation of APP_init done above is repeated for the experimental data with SORLA. Instead of xdata8, xdata8s is used

for j=1:ws
func=@(APP)( APP.* (1+ Kg1+ Kg2+ Kcs1.* (1+ Kc1.* ((- (1+ Kc2+ Kc1.* (1+ Kcs1.* APP./ Kma)) +  sqrt((1+ Kc2+ Kc1.* (1+ Kcs1.* APP./ Kma)).^2- 4.* (2.* Kc3.* (1+ Kcs2.* APP.^2./ Kmad)).* (- Atot)))./ (2.* (2.* Kc3.* (1+ Kcs2.* APP.^2./ Kmad))))./ Kma)+ Kee1.* (1+ Kb1.* ((- (1+ Kb2+ Kb1.* (1+ Kee1.* APP./ Kmb)) +  sqrt((1+ Kb2+ Kb1.* (1+ Kee1.* APP./ Kmb)).^2- 4.* (2.* Kb3.* (1+ Kee2.* APP.^2./ Kmbd)).* (- Btot)))./ (2.* (2.* Kb3.* (1+ Kee2.* APP.^2./ Kmbd))))./ Kmb))+  2.* (APP.^2).* (Kg3+ Kcs2.* (1+ Kc3.* (((- (1+ Kc2+ Kc1.* (1+ Kcs1.* APP./ Kma)) +  sqrt((1+ Kc2+ Kc1.* (1+ Kcs1.* APP./ Kma)).^2- 4.* (2.* Kc3.* (1+ Kcs2.* APP.^2./ Kmad)).* (- Atot)))./ (2.* (2.* Kc3.* (1+ Kcs2.* APP.^2./ Kmad)))).^2)./ Kmad)+ Kee2.* (1+ Kb3.* (((- (1+ Kb2+ Kb1.* (1+ Kee1.* APP./ Kmb)) +  sqrt((1+ Kb2+ Kb1.* (1+ Kee1.* APP./ Kmb)).^2- 4.* (2.* Kb3.* (1+ Kee2.* APP.^2./ Kmbd)).* (- Btot)))./ (2.* (2.* Kb3.* (1+ Kee2.* APP.^2./ Kmbd)))).^2)./ Kmbd))-  xdata8s(j,1));
appFSOLVEs(1,j)=fzero(func,[0 Ps(j)],optimset('fzero'));
end
 
% Then, SOLVE for free APPg1 and APPg2 given the total amount of APP in monomer and in dimer, respectively
% Step~1: solve the conserved total amount of alpha, beta, and APP in monomer and in dimer processing

 apps=appFSOLVEs';
alphas  = (- (1+ Kc2+ Kc1.* (1+ Kcs1.* apps./ Kma)) +  sqrt((1+ Kc2+ Kc1.* (1+ Kcs1.* apps./ Kma)).^2- 4.* (2.* Kc3.* (1+ Kcs2.* apps.^2./ Kmad)).* (- Atot)))./ (2.* (2.* Kc3.* (1+ Kcs2.* apps.^2./ Kmad)));
betas   = (- (1+ Kb2+ Kb1.* (1+ Kee1.* apps./ Kmb)) +  sqrt((1+ Kb2+ Kb1.* (1+ Kee1.* apps./ Kmb)).^2- 4.* (2.* Kb3.* (1+ Kee2.* apps.^2./ Kmbd)).* (- Btot)))./ (2.* (2.* Kb3.* (1+ Kee2.* apps.^2./ Kmbd)));

Atotms  = (alphas.* Kc1).* (1+ Kcs1.* apps./ Kma);
Atotds  = Kc2.* alphas +  2.* Kc3.* (alphas.^2).* (1+ Kcs2.* (apps.^2)./ Kmad);
Btotms  = (betas.* Kb1).* (1+ Kee1.* apps./ Kmb);
Btotds  = Kb2.* betas +  2.* Kb3.* (betas.^2).* (1+ Kee2.* (apps.^2)./ Kmbd);
APPtotms    = apps.* (Kg1+ Kcs1.* (1+ Kc1.* alphas./ Kma)+ Kee1.* (1+ Kb1.* betas./ Kmb));
APPtotds    = Kg2.* apps+ 2.* (apps.^2).* (Kg3+ Kcs2.* (1+ Kc3.* (alphas.^2)./ Kmad)+ Kee2.* (1+ Kb3.* (betas.^2)./ Kmbd));
 
% Step 2: solve for the corresponding free values (APPg1 and APPg2) such that APPms* Kg1 and APPds* Kg1 correspond to APPG1 and APPG2 in the model representation, respectively. (See Equations~\ref{MonoDimerInitW})

for js=1:ws
funcs=@(APPms)(APPms.* (Kg1+ Kcs1.* (1+ Kc1.* (Atotms(js,1)./ (Kc1.* (1+ Kcs1.* APPms./ Kma)))./ Kma)+ Kee1.* (1+ Kb1.* (Btotms(js,1)./ (Kb1.* (1+ Kee1.* APPms./ Kmb)))./ Kmb))+  Ks1.* (SORtotm./ (1+  Ks1.* APPms)).* APPms -  APPtotms(js,1));
appFSOLVEms(1,js)=fzero(funcs,[0 APPtotms(js)],optimset('fzero'));      
end 
 
for js=1:ws
funcs=@(APPds)(Kg2.* APPds +  2.* (APPds.^2).* (Kg3+ Kcs2.* (1+ Kc3.* (((- Kc2 +  sqrt(Kc2.^2- 4.* (2.* Kc3.* (1+ Kcs2.* (APPds.^2)./ Kmad)).* (- Atotds(js,1))))./ (4.* Kc3.* (1+ Kcs2.* (APPds.^2)./ Kmad))).^2)./ Kmad)+ Kee2.* (1+ Kb3.* (((- Kb2 +  sqrt(Kb2.^2- 4.* (2.* Kb3.* (1+ Kee2.* (APPds.^2)./ Kmbd)).* (- Btotds(js,1))))./ (4.* Kb3.* (1+ Kee2.* (APPds.^2)./ Kmbd))).^2)./ Kmbd))+  Ks2.* (SORtotd./ (1+  Ks2.* APPds)).* APPds -  APPtotds(js,1));
appFSOLVEds(1,js)=fzero(funcs,[0 APPtotds(js)],optimset('fzero'));     
end 
 
%% SUMMARY of representations
% without SORLA (see Equations~\ref{eq:alpha5}~and~\ref{eq:beta5})
% alpha denotes alpha_init
% beta denotes beta_init
% Atot denotes the conserved amount of alpha-secretase
% Btot denotes the conserved amount of beta-secretase 
app=appFSOLVE';
alpha   = (- (1+ Kc2+ Kc1.* (1+ Kcs1.* app./ Kma)) +  sqrt((1+ Kc2+ Kc1.* (1+ Kcs1.* app./ Kma)).^2- 4.* (2.* Kc3.* (1+ Kcs2.* app.^2./ Kmad)).* (- Atot)))./ (2.* (2.* Kc3.* (1+ Kcs2.* app.^2./ Kmad)));
beta    = (- (1+ Kb2+ Kb1.* (1+ Kee1.* app./ Kmb)) +  sqrt((1+ Kb2+ Kb1.* (1+ Kee1.* app./ Kmb)).^2- 4.* (2.* Kb3.* (1+ Kee2.* app.^2./ Kmbd)).* (- Btot)))./ (2.* (2.* Kb3.* (1+ Kee2.* app.^2./ Kmbd)));
 
% with SORLA (see Equations~\ref{alpha12}~and~\ref{beta12})
% alphams.* Kc1 denotes alpha_1
% alphads.* Kc2 denotes alpha_2
% betams.* Kb1 denotes beta_1
% betads.* Kb2 denotes beta_2
% Atotms and Atotds denote the conserved amount of alpha in monomer and in dimer, respectively
% Btotms and Btotds denote the conserved amount of alpha in monomer and in dimer, respectively
% appms* Kg1 is APPG1 in the equations shown in Section~\ref{sec:MultiCompartmentmodel}
% appds* Kg1 is APPG2 in the equations shown in Section~\ref{sec:MultiCompartmentmodel}
appms=appFSOLVEms';
appds=appFSOLVEds';
appTOTS=app+ appms+ appds;
%monomer procssing with SORLA
alphams = Atotms./ (Kc1.* (1+ Kcs1.* appms./ Kma));
betams  = Btotms./ (Kb1.* (1+ Kee1.* appms./ Kmb));
%dimer procssing with SORLA
alphads = (- Kc2 +  sqrt(Kc2.^2- 4.* (2.* Kc3.* (1+ Kcs2.* (appds.^2)./ Kmad)).* (- Atotds)))./ (4.* Kc3.* (1+ Kcs2.* (appds.^2)./ Kmad));
betads  = (- Kb2 +  sqrt(Kb2.^2- 4.* (2.* Kb3.* (1+ Kee2.* (appds.^2)./ Kmbd)).* (- Btotds)))./ (4.* Kb3.* (1+ Kee2.* (appds.^2)./ Kmbd));
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%% fitting to the experimental data (see Equations~\ref{eq:sAPPalpha}~-~\ref{eq:sAPPalphabeta})
% with SORLA for monomer processing
fit11 =k6.* Kc1.* alpha.* Kcs1.* app./ Kma;% sAPPa
fit21= k4.* Kb1.* beta.* Kee1.* app./ Kmb;% sAPPb
% without SORLA for dimer processing
fit12 = 2.* k6d.* Kc3.* (alpha.^2).* Kcs2.* (app.^2)./ Kmad;% sAPPa
fit22= 2.* k4d.* Kb3.* (beta.^2).* Kee2.* (app.^2)./ Kmbd;% sAPPb
% sum of  products w/o SORLA in monomer and dimer
fit1 = (fit11+ fit12); % sAPPa
fit2 = (fit21+ fit22); % sAPPb
 
% fitting with SORLA monomer(refer to Equations16 in supplementary information)
% with SORLA for monomer processing
fit12s = k6.* Kc1.* alphams.* Kcs1.* appms./ Kma;% sAPPa
fit22s = k4.* Kb1.* betams.* Kee1.* appms./ Kmb;% sAPPb
% without SORLA for dimer processing
fit11s =2.* k6d.* Kc3.* (alphads.^2).* Kcs2.* (appds.^2)./ Kmad;% sAPPa
fit21s= 2.* k4d.* Kb3.* (betads.^2).* Kee2.* (appds.^2)./ Kmbd;% sAPPb
% sum of  products w/ SORLA in monomer and dimer
fit1s = (fit11s+ fit12s); % sAPPa
fit2s = (fit21s+ fit22s); % sAPPb


%RECALL: w and ws denote the number of experimental data without and with SORLA, respectively
% without SORLA
err11 = (fit1 -  data(:,2))./ sqrt((sum(data(:,2))./ w));
err22 = (fit2 -  data(:,3))./ sqrt((sum(data(:,3))./ w));
% with SORLA
errAPPs = (appTOTS -  datas(:,1))./ sqrt((sum(datas(:,1))./ ws));
err11s = (fit1s -  datas(:,2)) ./ sqrt((sum(datas(:,2))./ ws));
err22s = (fit2s -  datas(:,3)) ./ sqrt((sum(datas(:,3))./ ws));
% error vector
err=vertcat(errAPPs, err11, err22, err11s, err22s);
end 
end


